@@ -4,19 +4,20 @@
 #include <QtNetwork>
 #include <QtGui>
 #include <QDataStream>
-#include <QtMaemo5>
+
+#ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#endif
 
 //00:c0:9F:2B:A5:97
 
-WoLAN::WoLAN(QWidget *parent) :
+wolan::wolan(QWidget *parent) :
     QWidget(parent),
-    ui(new Ui::WoLAN)
+    ui(new Ui::wolan)
 {
     ui->setupUi(this);
-    //qDebug() << "Open input file";
     QString sFilename;
 
-    //sFilename = QDir().currentPath();
     sFilename = "/opt/wolan/wolan.conf";
     bEditMode = false;
     bAddMode=false;
@@ -25,25 +26,25 @@ WoLAN::WoLAN(QWidget *parent) :
     iCurrentTarget = tgList.lstTarget.size()-1;
     DisplayTarget (iCurrentTarget);
     ui->label->setText("             ");
-    //ui->progressBar->setValue(0);
-    //ui->progressBar->setMaximum(0);
     ui->fraBar->setVisible(false);
 }
 
-WoLAN::~WoLAN()
+wolan::~wolan()
 {
     delete ui;
 }
 
 
 
-void WoLAN::on_pushButton_clicked()
+void wolan::on_pushButton_clicked()
 {
     QString sMsg;
     int i,j;
     bool b;
 
     ui->pushButton->setEnabled(false);
+
+    /* prepare the magic packet and put it bMsg */
     QByteArray bMsg;
     for (i=0;i<=5;i++)
         bMsg.append("\xff");
@@ -51,12 +52,15 @@ void WoLAN::on_pushButton_clicked()
         for (j=0;j<17;j+=3)
             bMsg.append(ui->lMAC->text().mid(j,2).toInt(&b,16));
 
-    //<<QByteArray(16,ui->lMAC->text());
+     udpSocket.connectToHost(ui->lIP->text(), ui->lPort->text().toInt());
+    if (udpSocket.waitForConnected(1000))
+
+    {
+        udpSocket.write(bMsg);
+    }
+    udpSocket.close();
 
-    udpSocket.writeDatagram(bMsg,QHostAddress(ui->lIP->text()), ui->lPort->text().toInt());
     ui->label->setText("Sent at " +  QTime::currentTime().toString("hh:mm:ss"));
-    //QMaemo5InformationBox::information(this, "Sent at " +  QTime::currentTime().toString("hh:mm:ss"),
-    //                                            QMaemo5InformationBox::DefaultTimeout);
 
     timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(checkConnection()));
@@ -71,22 +75,21 @@ void WoLAN::on_pushButton_clicked()
     ui->fraBar->setVisible(true);
 }
 
-void WoLAN::checkConnection()
+void wolan::checkConnection()
 {
-    //timer->stop();
-
     ui->progressBar->setValue(ui->progressBar->value()+1);
-    //ui->lblTimer->setText(iNbrSeconds +" Sec");
-    //ui->lblTimer->show();
     tcpClient.connectToHost(ui->lIP->text(), ui->ltcpPort->text().toInt());
 
     if  (tcpClient.waitForConnected(1000))
     {
 
         ui->label->setText ("Host is up");
-        //ui->lblTimer->setText("");
+        #ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this, "Host is up",
                           QMaemo5InformationBox::NoTimeout);
+        #else
+        QMessageBox::information (this,"warning","Host is up",QMessageBox::Ok);
+        #endif
         timer->stop();
         qDebug("Connected!");
 
@@ -98,8 +101,13 @@ void WoLAN::checkConnection()
     } else if (--iNbrSeconds<=0)
     {
         ui->label->setText ("Host is not running");
+
+        #ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this, "Host is not running",
-                               QMaemo5InformationBox::NoTimeout);
+                          QMaemo5InformationBox::NoTimeout);
+        #else
+        QMessageBox::information (this,"warning","Host is not running",QMessageBox::Ok);
+        #endif
 
         qDebug("Not connected");
         timer->stop();
@@ -116,8 +124,13 @@ void WoLAN::checkConnection()
         timer->stop();
 
         // NOLBL ui->label->setText ("Cannot find IP address for " + ui->lIP->text());
+        #ifdef Q_WS_MAEMO_5
         QMaemo5InformationBox::information(this,"Cannot find IP address for <b>" + ui->lIP->text() + "</b>",
                                                     QMaemo5InformationBox::NoTimeout);
+        #else
+        QMessageBox::information (this,"warning","Cannot find IP address for <b>" + ui->lIP->text() + "</b>",QMessageBox::Ok);
+        #endif
+
         ui->label->setText("");
         ui->fraBar->setVisible(false);
         ui->frame->setVisible(true);
@@ -131,7 +144,7 @@ void WoLAN::checkConnection()
 
 
 
-void WoLAN::on_butAdd_clicked()
+void wolan::on_butAdd_clicked()
 {
     clsHost *tg;
     if (bEditMode || bAddMode)  // not Add but Save
@@ -168,13 +181,13 @@ void WoLAN::on_butAdd_clicked()
 }
 
 
-void WoLAN::on_butEdit_clicked()
+void wolan::on_butEdit_clicked()
 {
     bEditMode=true;
     SetInterfaceMode(true);
 }
 
-void WoLAN::DisplayTarget(int iTg)
+void wolan::DisplayTarget(int iTg)
 {
     clsHost *tg;
 
@@ -203,7 +216,7 @@ void WoLAN::DisplayTarget(int iTg)
     ui->label->setText("");
 }
 
-void WoLAN::on_butDel_clicked()
+void wolan::on_butDel_clicked()
 {
     if (bEditMode or bAddMode)  // not del but cancel
     {
@@ -225,7 +238,7 @@ void WoLAN::on_butDel_clicked()
 
 }
 
-void WoLAN::setButtons(bool bEnabled)
+void wolan::setButtons(bool bEnabled)
 {
     ui->pushButton->setEnabled(bEnabled);
     ui->butAdd->setEnabled(bEnabled);
@@ -235,7 +248,7 @@ void WoLAN::setButtons(bool bEnabled)
     ui->butPrev->setEnabled(( iCurrentTarget!=0 && iCurrentTarget !=-1 ) && bEnabled);
 }
 
-void WoLAN::SetInterfaceMode(bool bEdit)
+void wolan::SetInterfaceMode(bool bEdit)
 {
     // bEdit = true -> edit/add mode
     ui->butEdit->setEnabled(!bEdit);
@@ -260,12 +273,12 @@ void WoLAN::SetInterfaceMode(bool bEdit)
     //ui->lIP->setFocus();
 }
 
-void WoLAN::on_butPrev_clicked()
+void wolan::on_butPrev_clicked()
 {
     DisplayTarget(--iCurrentTarget);
 }
 
-void WoLAN::on_butNext_clicked()
+void wolan::on_butNext_clicked()
 {
     DisplayTarget(++iCurrentTarget);
 }
