@@ -1,5 +1,5 @@
-#ifndef WOLAN_H
-#define WOLAN_H
+#ifndef wolan_H
+#define wolan_H
 
 #include <QWidget>
 #include <QTcpSocket>
@@ -7,19 +7,19 @@
 #include "clshostlist.h"
 
 namespace Ui {
-    class WoLAN;
+    class wolan;
 }
 
-class WoLAN : public QWidget
+class wolan : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit WoLAN(QWidget *parent = 0);
-    ~WoLAN();
+    explicit wolan(QWidget *parent = 0);
+    ~wolan();
 
 private:
-    Ui::WoLAN *ui;
+    Ui::wolan *ui;
     QTimer *timer;
     int iNbrSeconds;
     QTcpSocket tcpClient;
@@ -50,4 +50,4 @@ private slots:
 
 };
 
-#endif // WOLAN_H
+#endif // wolan_H
